@@ -14,10 +14,12 @@ our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
   blessed refaddr reftype weaken unweaken isweak
 
+  isbool
+
   dualvar isdual isvstring looks_like_number openhandle readonly set_prototype
   tainted
 );
-our $VERSION    = "1.51";
+our $VERSION    = "1.57";
 $VERSION =~ tr/_//d;
 
 require List::Util; # List::Util loads the XS
@@ -36,14 +38,14 @@ unless (defined &isvstring) {
 }
 
 sub export_fail {
-  if (grep { /^(?:weaken|isweak)$/ } @_ ) {
-    require Carp;
-    Carp::croak("Weak references are not implemented in the version of perl");
-  }
-
   if (grep { /^isvstring$/ } @_ ) {
     require Carp;
-    Carp::croak("Vstrings are not implemented in the version of perl");
+    Carp::croak("Vstrings are not implemented in this version of perl");
+  }
+
+  if (grep { /^isbool$/ } @_ ) {
+    require Carp;
+    Carp::croak("isbool is not implemented in this version of perl");
   }
 
   @_;
@@ -134,6 +136,11 @@ is returned.
     $obj  = bless {}, "Foo";
     $type = reftype $obj;               # HASH
 
+Note that for internal reasons, all precompiled regexps (C<qr/.../>) are
+blessed references; thus C<ref()> returns the package name string C<"Regexp">
+on these but C<reftype()> will return the underlying C structure type of
+C<"REGEXP"> in all capitals.
+
 =head2 weaken
 
     weaken( $ref );
@@ -212,6 +219,16 @@ B<NOTE>: Copying a weak reference creates a normal, strong, reference.
 
 =head1 OTHER FUNCTIONS
 
+=head2 isbool
+
+    my $bool = isbool( $var );
+
+I<Available only since perl 5.35.3 onwards.>
+
+Returns true if the given variable is boolean in nature - that is, it is the
+result of a boolean operator (such as C<defined>, C<exists>, or a numerical or
+string comparison), or is a variable that is copied from one.
+
 =head2 dualvar
 
     my $var = dualvar( $num, $string );
@@ -236,24 +253,24 @@ true.
     $dual = isdual($foo);               # true
 
 Note that a scalar can be made to have both string and numeric content through
-numeric operations:
+standard operations:
 
     $foo = "10";
     $dual = isdual($foo);               # false
     $bar = $foo + 0;
     $dual = isdual($foo);               # true
 
-Note that although C<$!> appears to be a dual-valued variable, it is
-actually implemented as a magical variable inside the interpreter:
+The C<$!> variable is commonly dual-valued, though it is also magical in other
+ways:
 
     $! = 1;
+    $dual = isdual($!);                 # true
     print("$!\n");                      # "Operation not permitted"
-    $dual = isdual($!);                 # false
 
-You can capture its numeric and string content using:
-
-    $err = dualvar $!, $!;
-    $dual = isdual($err);               # true
+B<CAUTION>: This function is not as useful as it may seem. Dualvars are not a
+distinct concept in Perl, but a standard internal construct of all scalar
+values. Almost any value could be considered as a dualvar by this function
+through the course of normal operations.
 
 =head2 isvstring
 
@@ -319,16 +336,16 @@ Module use may give one of the following errors during import.
 
 =over
 
-=item Weak references are not implemented in the version of perl
-
-The version of perl that you are using does not implement weak references, to
-use L</isweak> or L</weaken> you will need to use a newer release of perl.
-
-=item Vstrings are not implemented in the version of perl
+=item Vstrings are not implemented in this version of perl
 
 The version of perl that you are using does not implement Vstrings, to use
 L</isvstring> you will need to use a newer release of perl.
 
+=item isbool is not implemented in this version of perl
+
+The version of perl that you are using does not implement stable boolean
+tracking, to use L</isbool> you will need to use a newer release of perl.
+
 =back
 
 =head1 KNOWN BUGS
